# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# We need to patch the test suite if we have Test::More < 0.96
%global old_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION < 0.96) ? 1 : 0);' 2>/dev/null || echo 0)

# Select the appropriate system speller
%if 0%{?fedora} > 8 || 0%{?rhel} > 5
%global speller hunspell
%else
%global speller aspell
%endif

# Note: optional dependency Sub::Util is packaged with Scalar-List-Utils ≥ 1.40 (August 2014, F-21 onwards)

# TODO: BR: perl(Test::Pod::No404s) when available

Name:		perl-Try-Tiny
Summary:	Minimal try/catch with proper localization of $@
Version:	0.28
Release:	1.%{__distinit}%{__distvers}
License:	MIT
Group:		Development/Libraries
URL:		http://search.cpan.org/dist/Try-Tiny
Source0:	http://search.cpan.org/CPAN/authors/id/E/ET/ETHER/Try-Tiny-%{version}.tar.gz
Patch0:		Try-Tiny-0.28-spelling.patch
Patch1:		Try-Tiny-0.28-old-Test::More.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl
%if 0%{?fedora} > 20 || 0%{?rhel} > 7
BuildRequires:	perl-generators
%endif
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module
BuildRequires:	perl(Carp)
BuildRequires:	perl(constant)
BuildRequires:	perl(Exporter) >= 5.57
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(Test::More)
# Optional Tests
BuildRequires:	perl(Capture::Tiny) >= 0.12
BuildRequires:	perl(CPAN::Meta) >= 2.120900
BuildRequires:	perl(CPAN::Meta::Check) >= 0.011
BuildRequires:	perl(CPAN::Meta::Requirements)
# Extra Tests
%if 0%{!?perl_bootstrap:1}
BuildRequires:	perl(blib)
BuildRequires:	perl(IO::Handle)
BuildRequires:	perl(IPC::Open3)
BuildRequires:	perl(Pod::Coverage::TrustPod)
BuildRequires:	perl(Pod::Wordlist)
BuildRequires:	perl(Test::CPAN::Changes)
BuildRequires:	perl(Test::CPAN::Meta)
BuildRequires:	perl(Test::EOL)
BuildRequires:	perl(Test::Kwalitee)
BuildRequires:	perl(Test::MinimumVersion)
BuildRequires:	perl(Test::Mojibake)
BuildRequires:	perl(Test::NoTabs)
BuildRequires:	perl(Test::Pod) >= 1.41
BuildRequires:	perl(Test::Pod::Coverage) >= 1.08
BuildRequires:	perl(Test::Portability::Files)
BuildRequires:	perl(Test::Spelling) >= 0.12, %{speller}-en
%endif
# Runtime
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

# Sub::Util is preferred to Sub::Name, but isn't always available
%if 0%{?fedora} > 20 || 0%{?rhel} > 7
BuildRequires:	perl(Sub::Util)
Requires:	perl(Sub::Util)
%else
BuildRequires:	perl(Sub::Name) >= 0.08
Requires:	perl(Sub::Name) >= 0.08
%endif

%description
This module provides bare bones try/catch statements that are designed to
minimize common mistakes with eval blocks, and NOTHING else.

This is unlike TryCatch, which provides a nice syntax and avoids adding
another call stack layer, and supports calling return from the try block to
return from the parent subroutine. These extra features come at a cost of a
few dependencies, namely Devel::Declare and Scope::Upper that are occasionally
problematic, and the additional catch filtering uses Moose type constraints,
which may not be desirable either.

%prep
%setup -q -n Try-Tiny-%{version}

# Keep our spell checker happy
%patch0

# We need to patch the test suite if we have Test::More < 0.96
%if %{old_test_more}
%patch1
%endif

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} %{buildroot}

%check
make test
%if 0%{!?perl_bootstrap:1}
LANG=en_US make test TEST_FILES="$(echo $(find xt/ -name '*.t'))"
%endif

%clean
rm -rf %{buildroot}

%files
%if 0%{?_licensedir:1}
%license LICENCE
%else
%doc LICENCE
%endif
%doc Changes CONTRIBUTING README t/
%{perl_vendorlib}/Try/
%{_mandir}/man3/Try::Tiny.3*

%changelog
* Mon Jan  9 2017 Paul Howarth <paul@city-fan.org> - 0.28-1
- Update to 0.28
  - Enabled some tests of finally blocks that were disabled on 5.6, now that
    that functionality works (since 0.13) (GH#4)

* Tue Aug 16 2016 Paul Howarth <paul@city-fan.org> - 0.27-1
- Update to 0.27
  - "finally" blocks are now run for all methods of leaving the try block
     (including via exit, goto) (CPAN RT#112099)
  - Switch from finalizers using an array to a hash, to resolve segfaults when
    creating a pseudofork on MSWin before perl 5.20
    (karenetheridge/Sub-Name/#3)
  - Repository moved to the github p5sagit organization (the primary is on
    shadowcat, mirrored to github)
- Fix FTBFS when perl is not in the minimal buildroot
- BR: perl-generators where available
- Simplify find command using -delete
- Update patches as needed

* Fri Dec 11 2015 Paul Howarth <paul@city-fan.org> - 0.24-1
- Update to 0.24
  - Fix syntax of example code (PR#22)
  - 'perl' removed from prerequisite recommendations, to avoid tripping up CPAN
    clients
  - Sub::Util is used preferentially to Sub::Name in most cases (PR#27)
- This release by ETHER → update source URL
- Update patch for building with Test::More < 0.88
- Add patch to satisfy spell checker

* Wed Sep 10 2014 Paul Howarth <paul@city-fan.org> - 0.22-3
- Use %%license where possible

* Tue Apr 29 2014 Paul Howarth <paul@city-fan.org> - 0.22-1
- Update to 0.22
  - Add optional test deps as recommended prereqs
    (https://github.com/doy/try-tiny/pull/18)
- Update patch for building with Test::More < 0.88

* Tue Apr 15 2014 Paul Howarth <paul@city-fan.org> - 0.21-1
- Update to 0.21
  - Also skip the test if Capture::Tiny is too old
    (https://github.com/doy/try-tiny/issues/17)

* Sat Mar 22 2014 Paul Howarth <paul@city-fan.org> - 0.20-1
- Update to 0.20
  - Documentation updates
- Update patch for building with Test::More < 0.88
- Drop obsoletes/provides for old tests sub-package
- Drop support for old distributions prior to FC-5:
  - Drop %%defattr, redundant since rpm 4.4
  - Drop patch for building with ExtUtils::MakeMaker < 6.30

* Fri Feb 28 2014 Paul Howarth <paul@city-fan.org> - 0.19-2
- Don't run the extra tests when bootstrapping

* Thu Jan 23 2014 Paul Howarth <paul@city-fan.org> - 0.19-1
- Update to 0.19
  - Fix an obscure issue with loading modules during global destruction
    (https://github.com/doy/try-tiny/pull/11)
  - Documentation updates (https://github.com/doy/try-tiny/pull/12)
- Add patch to support building with Test::More < 0.88 again

* Sat Aug 17 2013 Paul Howarth <paul@city-fan.org> - 0.18-1
- Update to 0.18
  - Fix tests for pre-Test-More-0.88 (https://github.com/doy/try-tiny/pull/10)
- Drop upstreamed patch for building with Test::More < 0.88

* Sat Aug 17 2013 Paul Howarth <paul@city-fan.org> - 0.17-1
- Update to 0.17
  - Work around Perl RT#119311, which was causing incorrect error messages in
    some cases during global destruction
    (https://github.com/doy/try-tiny/pull/9)
- Add patch to support building with Test::More < 0.88

* Sun Jul 21 2013 Paul Howarth <paul@city-fan.org> - 0.16-2
- Perl 5.18 rebuild

* Wed Jul 10 2013 Paul Howarth <paul@city-fan.org> - 0.16-1
- Update to 0.16
  - Remove accidental Sub::Name test dependency

* Tue Jul  9 2013 Paul Howarth <paul@city-fan.org> - 0.15-1
- Update to 0.15
  - Optionally use Sub::Name to name the try/catch/finally blocks, if available
- BR:/R: perl(Sub::Name)

* Sat Jul  6 2013 Paul Howarth <paul@city-fan.org> - 0.14-1
- Update to 0.14
  - Also throw an exception for catch/finally in scalar context (CPAN RT#81070)

* Fri Jul  5 2013 Paul Howarth <paul@city-fan.org> - 0.13-1
- Update to 0.13
  - Fix tests failing on 5.6.x due to differing DESTROY semantics
  - Excise superfluous local($@) call - 7%% speedup
  - Fix broken URLs (CPAN RT#55659)
  - Proper exception on erroneous usage of bare catch/finally (CPAN RT#81070)
  - Proper exception on erroneous use of multiple catch{} blocks
  - Clarify exception occuring on unterminated try block (CPAN RT#75712)
  - Fix the prototypes shown in docs to match code (CPAN RT#79590)
  - Warn loudly on exceptions in finally() blocks
  - dzilify
- Ship upstream LICENSE and README files
- Classify buildreqs by usage
- Add buildreqs for extra tests and explicitly run them

* Wed Jan  2 2013 Paul Howarth <paul@city-fan.org> - 0.12-1
- Update to 0.12
  - Documentation fixes

* Tue Aug 28 2012 Paul Howarth <paul@city-fan.org> - 0.11-7
- BR:/R: perl(Exporter)

* Tue Jun 12 2012 Paul Howarth <paul@city-fan.org> - 0.11-5
- Perl 5.16 rebuild

* Mon Mar 26 2012 Paul Howarth <paul@city-fan.org> - 0.11-4
- BR: perl(Carp)
- Obsolete/provide old tests subpackage from Fedora
- Don't need to remove empty directories from buildroot
- Drop support for distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Sun Sep  4 2011 Paul Howarth <paul@city-fan.org> - 0.11-1
- Update to 0.11
  - Clarify some documentation

* Sat Jul  2 2011 Paul Howarth <paul@city-fan.org> - 0.09-2
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Mon Nov 29 2010 Paul Howarth <paul@city-fan.org> - 0.09-1
- Update to 0.09
  - Fix require vs. use issue in blead (CPAN RT#63410)
  - Don't index Try::Tiny::ScopeGuard
- This release by DOY -> update source URL

* Fri Oct 22 2010 Paul Howarth <paul@city-fan.org> - 0.07-1
- Update to 0.07
  - Allow multiple finally blocks
  - Pass the error, if any, to finally blocks when called
- This release by RJBS -> update source URL

* Thu Jun 24 2010 Paul Howarth <paul@city-fan.org> - 0.06-2
- Rebuild for perl 5.12.1 in Rawhide

* Thu May 27 2010 Paul Howarth <paul@city-fan.org> - 0.06-1
- Update to 0.06 (test suite fix upstreamed)

* Thu May 27 2010 Paul Howarth <paul@city-fan.org> - 0.05-1
- Update to 0.05 (documentation fixes and clarifications)
- Add patch for test suite with Test::More < 0.88

* Mon May 17 2010 Paul Howarth <paul@city-fan.org> - 0.04-2
- Fix dist tag for RHEL-6 Beta

* Sat Jan 23 2010 Paul Howarth <paul@city-fan.org> - 0.04-1
- Update to 0.04
  - Restore list context propagation for catch blocks
  - Fix a bug where finally blocks weren't always invoked

* Fri Jan 22 2010 Paul Howarth <paul@city-fan.org> - 0.03-1
- Update to 0.03
  - Support for 'finally' blocks
  - More documentation and tests
  - Sets $@ to the previous value at the beginning of the eval
- Dist tag for Rawhide no longer needs special-casing

* Wed Sep 16 2009 Paul Howarth <paul@city-fan.org> - 0.02-1
- Initial RPM package
